==> spellathon-5.21.tar.gz: spellathon-5.21/src/logic/game.h <==
/*
 * Copyright (c) 2008, Girish Rao
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the <ORGANIZATION> nor the names of its contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _GAME_H_
#define _GAME_H_

#include <string>
#include <vector>

using std::string;
using std::vector;

namespace Spellathon
{
	class Dict;
	class Solver;

	class Game {
	public:
		Game(Dict *dct);
		~Game();
		bool play(bool precomp, int minsol, int maxsol); 
		bool solve(string letters);
		string sig() const  { if (found_) return sig_; else return ""; }
		const vector<string>& words() const;
		static int sidxcmp(const void *a, const void *b);
	private:
		bool _play(int minsol, int maxsol);
		bool _play_precomp(int minsol, int maxsol);
	private:
		Dict *dct_;
		Solver *sol_;
		string sig_;
		bool found_;
		vector<string> dummy;
	};
}

#endif /* _GAME_H_ */

==> spellathon-5.34.tar.gz: spellathon-5.34/src/logic/game.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _GAME_H_
#define _GAME_H_

#include <string>
#include <vector>

#ifndef SPTH_CL
#include <QObject>
#endif /* !SPTH_CL */

using std::string;
using std::vector;

namespace Spellathon
{
	class Dict;
	class Solver;

#ifdef SPTH_CL
	class Game {
#else
	class Game : public QObject {
		Q_OBJECT
#endif /* SPTH_CL */
	public:
		Game(Dict *dct);
		~Game();

		bool play(bool precomp, int minsol, int maxsol); 
		bool solve(string letters);
		string sig() const  { if (found_) return sig_; else return ""; }
		const vector<string>& words();
		static int sidxcmp(const void *a, const void *b);
#ifndef SPTH_CL
	signals: 
		void progressbarOpen(int, int);
		void progressbarClose();
		void progressbarUpdate(int);
#endif /* !SPTH_CL */
	private:
		bool _play(int minsol, int maxsol);
		bool _play_precomp(int minsol, int maxsol);
	private:
		Dict *dct_;
		Solver *sol_;
		string sig_;
		bool found_;
		vector<string> words_;
	};
}

#endif /* _GAME_H_ */
